import React from "react";
import Navigation from "../components/layout/Navigation";
import Footer from "../components/layout/Footer";
import { Shield, Lock, Cloud, Eye } from "lucide-react";

const PrivacyPage: React.FC = () => {
  return (
    <div className="min-h-screen bg-white">
      <Navigation />
      <main className="pt-20">
        {/* Hero Section */}
        <section className="py-16 bg-gradient-to-br from-primary-50 to-success-50">
          <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
            <div className="w-16 h-16 bg-primary-600 rounded-full flex items-center justify-center mx-auto mb-6">
              <Shield className="w-8 h-8 text-white" />
            </div>
            <h1 className="text-4xl md:text-5xl font-bold text-neutral-900 mb-4">
              Privacy & Security
            </h1>
            <p className="text-xl text-neutral-600 max-w-2xl mx-auto">
              Your privacy is our priority. Learn how we protect your data and
              keep your family's information secure.
            </p>
          </div>
        </section>

        {/* Privacy Principles */}
        <section className="py-16">
          <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8">
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-8 mb-16">
              <div className="text-center">
                <div className="w-12 h-12 bg-primary-100 rounded-xl flex items-center justify-center mx-auto mb-4">
                  <Lock className="w-6 h-6 text-primary-600" />
                </div>
                <h3 className="font-semibold text-neutral-900 mb-2">
                  End-to-End Encryption
                </h3>
                <p className="text-sm text-neutral-600">
                  Your data is encrypted both in transit and at rest
                </p>
              </div>
              <div className="text-center">
                <div className="w-12 h-12 bg-success-100 rounded-xl flex items-center justify-center mx-auto mb-4">
                  <Cloud className="w-6 h-6 text-success-600" />
                </div>
                <h3 className="font-semibold text-neutral-900 mb-2">
                  Apple CloudKit
                </h3>
                <p className="text-sm text-neutral-600">
                  Secure cloud storage using Apple's infrastructure
                </p>
              </div>
              <div className="text-center">
                <div className="w-12 h-12 bg-purple-100 rounded-xl flex items-center justify-center mx-auto mb-4">
                  <Eye className="w-6 h-6 text-purple-600" />
                </div>
                <h3 className="font-semibold text-neutral-900 mb-2">
                  No Data Mining
                </h3>
                <p className="text-sm text-neutral-600">
                  We don't analyze or sell your personal information
                </p>
              </div>
              <div className="text-center">
                <div className="w-12 h-12 bg-orange-100 rounded-xl flex items-center justify-center mx-auto mb-4">
                  <Shield className="w-6 h-6 text-orange-600" />
                </div>
                <h3 className="font-semibold text-neutral-900 mb-2">
                  GDPR Compliant
                </h3>
                <p className="text-sm text-neutral-600">
                  Full compliance with global privacy regulations
                </p>
              </div>
            </div>

            {/* Table of Contents */}
            <div className="bg-neutral-50 rounded-xl p-6 mb-12">
              <h2 className="text-xl font-semibold text-neutral-900 mb-4">Table of Contents</h2>
              <nav className="grid grid-cols-1 md:grid-cols-2 gap-2">
                <a href="#overview" className="text-primary-600 hover:text-primary-700 transition-colors py-1">1. Overview</a>
                <a href="#information-collected" className="text-primary-600 hover:text-primary-700 transition-colors py-1">2. Information We Collect</a>
                <a href="#how-we-use" className="text-primary-600 hover:text-primary-700 transition-colors py-1">3. How We Use Your Information</a>
                <a href="#data-storage" className="text-primary-600 hover:text-primary-700 transition-colors py-1">4. Data Storage & Security</a>
                <a href="#data-sharing" className="text-primary-600 hover:text-primary-700 transition-colors py-1">5. Data Sharing</a>
                <a href="#cookies-analytics" className="text-primary-600 hover:text-primary-700 transition-colors py-1">6. Cookies & Analytics</a>
                <a href="#international-transfers" className="text-primary-600 hover:text-primary-700 transition-colors py-1">7. International Data Transfers</a>
                <a href="#your-rights" className="text-primary-600 hover:text-primary-700 transition-colors py-1">8. Your Rights</a>
                <a href="#children-privacy" className="text-primary-600 hover:text-primary-700 transition-colors py-1">9. Children's Privacy</a>
                <a href="#policy-changes" className="text-primary-600 hover:text-primary-700 transition-colors py-1">10. Policy Changes</a>
                <a href="#contact" className="text-primary-600 hover:text-primary-700 transition-colors py-1">11. Contact Us</a>
              </nav>
            </div>

            {/* Privacy Policy Content */}
            <div className="space-y-12">
              {/* Overview */}
              <section id="overview" className="scroll-mt-24">
                <div className="border-l-4 border-primary-500 pl-6 mb-8">
                  <h2 className="text-3xl font-bold text-neutral-900 mb-4">Privacy Policy</h2>
                  <p className="text-lg text-neutral-600 mb-2">
                    <strong>Effective Date:</strong> June 19, 2025
                  </p>
                  <p className="text-lg text-neutral-600">
                    <strong>Last Updated:</strong> June 19, 2025
                  </p>
                </div>
                <div className="bg-blue-50 border border-blue-200 rounded-lg p-6">
                  <h3 className="text-lg font-semibold text-blue-900 mb-3">Our Commitment to Your Privacy</h3>
                  <p className="text-blue-800 leading-relaxed">
                    At ListLive, we believe privacy is a fundamental right. This policy explains how we collect, use, and protect your personal information when you use our family list-sharing application. We are committed to transparency and giving you control over your data.
                  </p>
                </div>
              </section>

              {/* Information We Collect */}
              <section id="information-collected" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">1. Information We Collect</h2>
                <div className="space-y-6">
                  <div>
                    <h3 className="text-xl font-semibold text-neutral-800 mb-3">Personal Information You Provide</h3>
                    <ul className="space-y-2 text-neutral-700 ml-4">
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>Lists, items, and notes you create within the app</li>
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>Account information required for Apple CloudKit synchronization</li>
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>Family member information when you choose to share lists</li>
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>Support communications when you contact us</li>
                    </ul>
                  </div>
                  <div>
                    <h3 className="text-xl font-semibold text-neutral-800 mb-3">Automatically Collected Information</h3>
                    <ul className="space-y-2 text-neutral-700 ml-4">
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>App usage analytics to improve performance and user experience</li>
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>Crash reports and error logs to identify and fix technical issues</li>
                      <li className="flex items-start"><span className="text-primary-500 mr-2">•</span>Device information (iOS version, device model) for compatibility purposes</li>
                    </ul>
                  </div>
                </div>
              </section>

              {/* How We Use Information */}
              <section id="how-we-use" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">2. How We Use Your Information</h2>
                <div className="bg-green-50 border border-green-200 rounded-lg p-6 mb-6">
                  <h3 className="text-lg font-semibold text-green-900 mb-3">Primary Purposes</h3>
                  <p className="text-green-800 mb-4">We use your information exclusively to provide and improve our service. We never use your personal data for advertising or marketing to third parties.</p>
                </div>
                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div className="border border-neutral-200 rounded-lg p-4">
                    <h4 className="font-semibold text-neutral-800 mb-2">Core Functionality</h4>
                    <ul className="space-y-1 text-sm text-neutral-600">
                      <li>• Sync lists across your devices</li>
                      <li>• Enable family list sharing</li>
                      <li>• Provide real-time updates</li>
                    </ul>
                  </div>
                  <div className="border border-neutral-200 rounded-lg p-4">
                    <h4 className="font-semibold text-neutral-800 mb-2">Service Improvement</h4>
                    <ul className="space-y-1 text-sm text-neutral-600">
                      <li>• Fix bugs and improve stability</li>
                      <li>• Enhance app performance</li>
                      <li>• Develop new features</li>
                    </ul>
                  </div>
                  <div className="border border-neutral-200 rounded-lg p-4">
                    <h4 className="font-semibold text-neutral-800 mb-2">Communication</h4>
                    <ul className="space-y-1 text-sm text-neutral-600">
                      <li>• Provide customer support</li>
                      <li>• Send security notifications</li>
                      <li>• Share important app updates</li>
                    </ul>
                  </div>
                  <div className="border border-neutral-200 rounded-lg p-4">
                    <h4 className="font-semibold text-neutral-800 mb-2">Legal Compliance</h4>
                    <ul className="space-y-1 text-sm text-neutral-600">
                      <li>• Comply with applicable laws</li>
                      <li>• Protect our legal rights</li>
                      <li>• Ensure platform security</li>
                    </ul>
                  </div>
                </div>
              </section>

              {/* Data Storage and Security */}
              <section id="data-storage" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">3. Data Storage & Security</h2>
                <div className="bg-purple-50 border border-purple-200 rounded-lg p-6 mb-6">
                  <h3 className="text-lg font-semibold text-purple-900 mb-3">Apple CloudKit Infrastructure</h3>
                  <p className="text-purple-800 leading-relaxed">
                    Your data is stored securely using Apple's CloudKit service, providing enterprise-grade security with privacy by design. Apple cannot access your personal data, and neither can we in most cases.
                  </p>
                </div>
                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div>
                    <h4 className="text-lg font-semibold text-neutral-800 mb-3">Security Measures</h4>
                    <ul className="space-y-2 text-neutral-700">
                      <li className="flex items-start"><span className="text-purple-500 mr-2">🔐</span>End-to-end encryption for all personal data</li>
                      <li className="flex items-start"><span className="text-purple-500 mr-2">🏢</span>Secure data centers with 24/7 monitoring</li>
                      <li className="flex items-start"><span className="text-purple-500 mr-2">💾</span>Automatic backups and data redundancy</li>
                      <li className="flex items-start"><span className="text-purple-500 mr-2">🛡️</span>Regular security audits and updates</li>
                    </ul>
                  </div>
                  <div>
                    <h4 className="text-lg font-semibold text-neutral-800 mb-3">Compliance Standards</h4>
                    <ul className="space-y-2 text-neutral-700">
                      <li className="flex items-start"><span className="text-purple-500 mr-2">✓</span>GDPR (General Data Protection Regulation)</li>
                      <li className="flex items-start"><span className="text-purple-500 mr-2">✓</span>CCPA (California Consumer Privacy Act)</li>
                      <li className="flex items-start"><span className="text-purple-500 mr-2">✓</span>SOC 2 Type II certification</li>
                      <li className="flex items-start"><span className="text-purple-500 mr-2">✓</span>ISO 27001 security standards</li>
                    </ul>
                  </div>
                </div>
              </section>

              {/* Data Sharing */}
              <section id="data-sharing" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">4. Data Sharing</h2>
                <div className="bg-red-50 border border-red-200 rounded-lg p-6 mb-6">
                  <h3 className="text-lg font-semibold text-red-900 mb-3">Our No-Sale Promise</h3>
                  <p className="text-red-800 leading-relaxed">
                    We never sell, trade, or rent your personal information to third parties. Your data is not a product – our app subscription is our business model.
                  </p>
                </div>
                <div className="space-y-4">
                  <h3 className="text-lg font-semibold text-neutral-800">Limited Sharing Scenarios</h3>
                  <div className="space-y-3">
                    <div className="border-l-4 border-green-400 pl-4">
                      <h4 className="font-medium text-neutral-800">Family Sharing (Your Choice)</h4>
                      <p className="text-neutral-600 text-sm">With family members you explicitly invite to shared lists</p>
                    </div>
                    <div className="border-l-4 border-yellow-400 pl-4">
                      <h4 className="font-medium text-neutral-800">Legal Requirements</h4>
                      <p className="text-neutral-600 text-sm">When required by law, court order, or to protect legal rights</p>
                    </div>
                    <div className="border-l-4 border-blue-400 pl-4">
                      <h4 className="font-medium text-neutral-800">Service Providers</h4>
                      <p className="text-neutral-600 text-sm">With vetted providers who help operate our app (bound by strict privacy agreements)</p>
                    </div>
                  </div>
                </div>
              </section>

              {/* Cookies & Analytics */}
              <section id="cookies-analytics" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">5. Cookies & Analytics</h2>
                <div className="space-y-6">
                  <div>
                    <h3 className="text-lg font-semibold text-neutral-800 mb-3">Website Cookies</h3>
                    <p className="text-neutral-700 mb-4">Our marketing website uses minimal cookies for:</p>
                    <ul className="space-y-2 text-neutral-700 ml-4">
                      <li className="flex items-start"><span className="text-blue-500 mr-2">•</span>Essential website functionality and security</li>
                      <li className="flex items-start"><span className="text-blue-500 mr-2">•</span>Anonymous usage analytics via Google Analytics</li>
                      <li className="flex items-start"><span className="text-blue-500 mr-2">•</span>Remembering your preferences and settings</li>
                    </ul>
                  </div>
                  <div>
                    <h3 className="text-lg font-semibold text-neutral-800 mb-3">Mobile App Analytics</h3>
                    <p className="text-neutral-700 mb-4">In the mobile app, we collect anonymized analytics including:</p>
                    <ul className="space-y-2 text-neutral-700 ml-4">
                      <li className="flex items-start"><span className="text-blue-500 mr-2">•</span>Feature usage patterns (which features are used most)</li>
                      <li className="flex items-start"><span className="text-blue-500 mr-2">•</span>Performance metrics (app speed, crash rates)</li>
                      <li className="flex items-start"><span className="text-blue-500 mr-2">•</span>General usage statistics (session length, frequency)</li>
                    </ul>
                    <p className="text-sm text-neutral-600 mt-4 bg-neutral-50 p-3 rounded">You can opt out of analytics in the app settings at any time.</p>
                  </div>
                </div>
              </section>

              {/* International Data Transfers */}
              <section id="international-transfers" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">6. International Data Transfers</h2>
                <div className="bg-blue-50 border border-blue-200 rounded-lg p-6">
                  <h3 className="text-lg font-semibold text-blue-900 mb-3">Global Infrastructure</h3>
                  <p className="text-blue-800 mb-4">
                    Apple CloudKit operates data centers worldwide to provide fast, reliable service. Your data may be stored and processed in countries different from where you live.
                  </p>
                  <div className="space-y-3 text-blue-800">
                    <p><strong>Safeguards in place:</strong></p>
                    <ul className="space-y-1 ml-4">
                      <li>• Standard Contractual Clauses for EU data transfers</li>
                      <li>• Adequacy decisions where applicable</li>
                      <li>• End-to-end encryption regardless of location</li>
                      <li>• Compliance with local data protection laws</li>
                    </ul>
                  </div>
                </div>
              </section>

              {/* Your Rights */}
              <section id="your-rights" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">7. Your Rights</h2>
                <div className="grid grid-cols-1 md:grid-cols-2 gap-6">
                  <div className="bg-green-50 border border-green-200 rounded-lg p-4">
                    <h4 className="font-semibold text-green-900 mb-2">Access & Control</h4>
                    <ul className="space-y-1 text-sm text-green-800">
                      <li>• View all your personal data</li>
                      <li>• Update or correct information</li>
                      <li>• Download your data</li>
                      <li>• Delete specific items or lists</li>
                    </ul>
                  </div>
                  <div className="bg-blue-50 border border-blue-200 rounded-lg p-4">
                    <h4 className="font-semibold text-blue-900 mb-2">Privacy Control</h4>
                    <ul className="space-y-1 text-sm text-blue-800">
                      <li>• Stop list sharing anytime</li>
                      <li>• Opt out of analytics</li>
                      <li>• Request data deletion</li>
                      <li>• Restrict data processing</li>
                    </ul>
                  </div>
                  <div className="bg-purple-50 border border-purple-200 rounded-lg p-4">
                    <h4 className="font-semibold text-purple-900 mb-2">Account Management</h4>
                    <ul className="space-y-1 text-sm text-purple-800">
                      <li>• Delete your account completely</li>
                      <li>• Export all data before deletion</li>
                      <li>• Revoke app permissions</li>
                      <li>• Change sharing preferences</li>
                    </ul>
                  </div>
                  <div className="bg-orange-50 border border-orange-200 rounded-lg p-4">
                    <h4 className="font-semibold text-orange-900 mb-2">Legal Rights (EU/CA)</h4>
                    <ul className="space-y-1 text-sm text-orange-800">
                      <li>• Object to data processing</li>
                      <li>• Data portability</li>
                      <li>• Lodge complaints with authorities</li>
                      <li>• Withdraw consent</li>
                    </ul>
                  </div>
                </div>
                <div className="mt-6 p-4 bg-neutral-100 rounded-lg">
                  <p className="text-sm text-neutral-700">
                    <strong>How to exercise your rights:</strong> Contact us at hhpendleton@gmail.com or use the in-app settings. We'll respond within 30 days and verify your identity before processing requests.
                  </p>
                </div>
              </section>

              {/* Children's Privacy */}
              <section id="children-privacy" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">8. Children's Privacy</h2>
                <div className="bg-yellow-50 border border-yellow-200 rounded-lg p-6">
                  <h3 className="text-lg font-semibold text-yellow-900 mb-3">Family-Friendly Design</h3>
                  <p className="text-yellow-800 mb-4">
                    ListLive is designed for family use, including households with children. We take special care to protect children's privacy and comply with laws like COPPA (Children's Online Privacy Protection Act).
                  </p>
                  <div className="space-y-3 text-yellow-800">
                    <p><strong>Our commitments:</strong></p>
                    <ul className="space-y-2 ml-4">
                      <li>• We don't knowingly collect personal information from children under 13 without verified parental consent</li>
                      <li>• Parents can review, delete, or refuse further collection of their child's information</li>
                      <li>• We don't require children to disclose more information than necessary to use the app</li>
                      <li>• Children's data receives the same security protections as adult data</li>
                    </ul>
                  </div>
                  <p className="text-yellow-800 mt-4">
                    <strong>If you believe a child has provided information without consent, please contact us immediately at hhpendleton@gmail.com.</strong>
                  </p>
                </div>
              </section>

              {/* Policy Changes */}
              <section id="policy-changes" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">9. Changes to This Policy</h2>
                <div className="space-y-4">
                  <p className="text-neutral-700 leading-relaxed">
                    We may update this Privacy Policy periodically to reflect changes in our practices, technology, legal requirements, or other factors. We will always notify you of material changes.
                  </p>
                  <div className="bg-neutral-50 border border-neutral-200 rounded-lg p-4">
                    <h4 className="font-semibold text-neutral-800 mb-2">How we notify you:</h4>
                    <ul className="space-y-1 text-neutral-700">
                      <li>• In-app notification for significant changes</li>
                      <li>• Email notification if you've provided your email</li>
                      <li>• Updated "Last Modified" date at the top of this policy</li>
                      <li>• Notice on our website and app store listings</li>
                    </ul>
                  </div>
                  <p className="text-neutral-700">
                    Continued use of ListLive after changes indicates acceptance of the updated policy. If you disagree with changes, you can delete your account and stop using the service.
                  </p>
                </div>
              </section>

              {/* Contact */}
              <section id="contact" className="scroll-mt-24">
                <h2 className="text-2xl font-bold text-neutral-900 mb-6">10. Contact Us</h2>
                <div className="bg-primary-50 border border-primary-200 rounded-lg p-6">
                  <h3 className="text-lg font-semibold text-primary-900 mb-4">Privacy Questions & Requests</h3>
                  <div className="space-y-4 text-primary-800">
                    <div>
                      <p className="font-medium">Email:</p>
                      <p className="text-lg">hhpendleton@gmail.com</p>
                    </div>
                    <div>
                      <p className="font-medium">Response Time:</p>
                      <p>We respond to privacy inquiries within 72 hours and fulfill requests within 30 days.</p>
                    </div>
                    <div>
                      <p className="font-medium">What to include in your message:</p>
                      <ul className="space-y-1 ml-4">
                        <li>• Clear description of your request or question</li>
                        <li>• Your account identifier (if applicable)</li>
                        <li>• Verification information to confirm your identity</li>
                        <li>• Preferred method for our response</li>
                      </ul>
                    </div>
                  </div>
                </div>
                <div className="mt-6 text-center">
                  <p className="text-neutral-600">
                    Thank you for trusting ListLive with your family's information. Your privacy matters to us.
                  </p>
                </div>
              </section>
            </div>
          </div>
        </section>
      </main>
      <Footer />
    </div>
  );
};

export default PrivacyPage;
